==> engagementinsights-web-1.0.2.tgz: package/src/properties/Constants.ts <==
/*
* Constants.ts
* @author Abhilash Panwar (abpanwar)
* @copyright Microsoft 2020
* File containing constants for Engagement Insights properties.
*/

export class _Extensions {
  public static _SignalExt = 's';
  public static _SignalLongExt = 'signal';
}

export class _SignalExtKeys {
  public static _View = 'v';
  public static _Referrer = 'r';
  public static _Action = 't';
  public static _Click = 'k';  
  public static _Session = 's';  
  public static _User = 'u';
  public static _Host = 'h';
  public static _Sdk = 'z';
  public static _ExtKey = 'e';
}

export class _SharedKeys {
  public static _Type = 't';
  public static _Uri = 'u';
  public static _NameKey = 'n';
  public static _Domain = 'd';
  public static _Version = 'v';
  public static _Title = 'v';  
  public static _Class = 'c';
  public static _TimeZone = 'z';
  public static _Source = 's';
  public static _Id = 'i';
}

export class _UserExtKeys {
  public static _LocalId = 'd';
  public static _AuthId = 'a';
  public static _AuthType = 'u';
  public static _Email = 'e';
  public static _State = 's';
  public static _TimeSinceVisit = 't';
}

export class _ReferrerExtKeys {
  public static _PageTitle = 'p';
}

export class _ViewExtKeys {
  public static _Height = 'h';
  public static _Width = 'w';
  public static _VpHeight = 'g';
  public static _VpWidth = 'd';
  public static _ColorDepth = 'o';
  public static _PreviousViews = 'r';
  public static _SResolution = 's';
}

export class _ActionExtKeys {
  public static _ElapsedTime = 'e';
  public static _IsOutbound = 'o';
  public static _Target = 'g';
  public static _ElementId = 'm';
}

export class _ClickExtKeys {
  public static _Coordinates = 'c';
}

export class _SessionExtKeys {
  public static _Id = 'i';
  public static _Duration = 'd';
}

export class _UserStateValues {
  public static _New = 'new';
  public static _Returning = 'returning';
}

export const _ViewEventName = 'view';
export const _ViewSchemaVersion = '0.0';
export const _ActionEventName = 'action';
export const _ActionSchemaVersion = '0.0';
export const _SDKVersion = 'EI-JS-0.0.17';
export const _emptyString = '';
export const _PageViewType = 'page';
export const _EIPreviousKey = 'EISession.Previous';
export const _EISessionKey = 'EISession.Id';
export const _MSEI = '_msei';
export const _UserMappingEventName = 'usermapping';
export const _UserMappingEventVersion = '0.0';
export const _UserMappingStorageKey = 'EIMappings';
export const _DayToMilliseconds = 24*60*60*1000;

==> engagementinsights-web-1.0.3.tgz: package/src/properties/Constants.ts <==
/*
* Constants.ts
* @author Abhilash Panwar (abpanwar)
* @copyright Microsoft 2020
* File containing constants for Engagement Insights properties.
*/

export class _Extensions {
  public static _SignalExt = 's';
  public static _SignalLongExt = 'signal';
}

export class _SignalExtKeys {
  public static _View = 'v';
  public static _Referrer = 'r';
  public static _Action = 't';
  public static _Click = 'k';  
  public static _Session = 's';  
  public static _User = 'u';
  public static _Host = 'h';
  public static _Sdk = 'z';
  public static _ExtKey = 'e';
}

export class _SharedKeys {
  public static _Type = 't';
  public static _Uri = 'u';
  public static _NameKey = 'n';
  public static _Domain = 'd';
  public static _Version = 'v';
  public static _Title = 'v';
  public static _Class = 'c';
  public static _TimeZone = 'z';
  public static _Source = 's';
  public static _Id = 'i';
}

export class _UserExtKeys {
  public static _LocalId = 'd';
  public static _AuthId = 'a';
  public static _AuthType = 'u';
  public static _Email = 'e';
  public static _State = 's';
  public static _TimeSinceVisit = 't';
}

export class _ReferrerExtKeys {
  public static _PageTitle = 'p';
}

export class _ViewExtKeys {
  public static _Height = 'h';
  public static _Width = 'w';
  public static _VpHeight = 'g';
  public static _VpWidth = 'd';
  public static _ColorDepth = 'o';
  public static _PreviousViews = 'r';
  public static _SResolution = 's';
}

export class _ActionExtKeys {
  public static _ElapsedTime = 'e';
  public static _IsOutbound = 'o';
  public static _Target = 'g';
  public static _ElementId = 'm';
}

export class _ClickExtKeys {
  public static _Coordinates = 'c';
}

export class _SessionExtKeys {
  public static _Id = 'i';
  public static _Duration = 'd';
}

export class _UserStateValues {
  public static _New = 'new';
  public static _Returning = 'returning';
}

export const _ViewEventName = 'view';
export const _ViewSchemaVersion = '1.0';
export const _ActionEventName = 'action';
export const _ActionSchemaVersion = '1.0';
export const _SDKVersion = 'EI-JS-1.0.3';
export const _emptyString = '';
export const _PageViewType = 'page';
export const _EIPreviousKey = 'EISession.Previous';
export const _EISessionKey = 'EISession.Id';
export const _MSEI = '_msei';
export const _UserMappingEventName = 'usermapping';
export const _UserMappingEventVersion = '1.0';
export const _UserMappingStorageKey = 'EIMappings';
export const _DayToMilliseconds = 24*60*60*1000;

// stats related
export const _StatsEventName = 'ei_sdk_stats';
export const _StatsSchemaVersion = '1.0';
export const _eventSendRequest = 'e_sr';
export const _eventSent = 'e_s';
export const _eventDiscarded = 'e_d';
export const _eventDiscardedUnknown = 'e_d_u';
export const _eventDiscardedNonRetryableStatus = 'e_d_nr';
export const _eventDiscardedInvalidEvent = 'e_d_ie';
export const _eventDiscardedSizeLimitExceeded = 'e_d_sle';
export const _eventDiscardedKillSwitch = 'e_d_ks';
export const _eventDiscardedQueueFull = 'e_d_qf';
